@@ -1,4 +1,4 @@
-__version__ = '0.16.2'
+__version__ = '0.18.4'
 
 # Import of utilix config for only once. NB: Should be first due to circular imports
 from utilix import uconfig
@@ -26,3 +26,9 @@ from . import analyses
 # Do not make all contexts directly available under straxen.
 # Otherwise we have straxen.demo() etc.
 from . import contexts
+
+try:
+    from . import holoviews_utils
+    from .holoviews_utils import *
+except ModuleNotFoundError:
+    pass
