@@ -264,9 +264,9 @@ class MongoDownloader(GridFsInterface):
         # We are going to set a place where to store the files. It's 
         # either specified by the user or we use these defaults:
         if store_files_at is None:
-            store_files_at = ('./resource_cache',
-                              '/tmp/straxen_resource_cache/' 
+            store_files_at = ('/tmp/straxen_resource_cache/',
                               '/dali/lgrandi/strax/resource_cache',
+                              './resource_cache',  
                               )
         elif not isinstance(store_files_at, (tuple, str, list)):
             raise ValueError(f'{store_files_at} should be tuple of paths!')
