@@ -22,12 +22,12 @@ MV_PREAMBLE = 'Muno-Veto Plugin: Same as the corresponding nVETO-PLugin.\n'
              'Specify as a tuple of length 120, or a number.'),
     strax.Option(
         'min_split_nv',
-        default=100, track=True,
+        default=0.063, track=True,
         help='Minimum height difference pe/sample between local minimum and maximum, '
              'that a pulse get split.'),
     strax.Option(
         'min_split_ratio_nv',
-        default=0, track=True,
+        default=0.75, track=True,
         help='Min ratio between local maximum and minimum to split pulse (zero to switch this off).'),
     strax.Option(
         'entropy_template_nv',
@@ -40,7 +40,7 @@ MV_PREAMBLE = 'Muno-Veto Plugin: Same as the corresponding nVETO-PLugin.\n'
     strax.Option('channel_map', track=False, type=immutabledict,
                  help="immutabledict mapping subdetector to (min, max) "
                       "channel number."),
-    strax.Option('gain_model_nv',
+    strax.Option('gain_model_nv', default=("CMT_model", ("to_pe_model_nv", "ONLINE")),
              help='PMT gain model. Specify as (model_type, model_config)'),
 )
 class nVETOHitlets(strax.Plugin):
@@ -88,33 +88,18 @@ class nVETOHitlets(strax.Plugin):
         self.to_pe[self.channel_range[0]:] = to_pe[:]
 
     def compute(self, records_nv, start, end):
-        # Search again for hits in records:
         hits = strax.find_hits(records_nv, min_amplitude=self.config['hit_min_amplitude_nv'])
-        # Merge concatenate overlapping  within a channel. This is important
-        # in case hits were split by record boundaries. In case we
-        # accidentally concatenate two PMT signals we split them later again.
-        hits = strax.concat_overlapping_hits(hits,
-                                             self.config['save_outside_hits_nv'],
-                                             self.channel_range,
-                                             start,
-                                             end)
-        hits = strax.sort_by_time(hits)
+        hits = remove_switched_off_channels(hits, self.to_pe)
 
-        # Now convert hits into temp_hitlets including the data field:
-        nsamples = 200
-        if len(hits):
-            nsamples = max(hits['length'].max(), nsamples)
-
-        temp_hitlets = np.zeros(len(hits), strax.hitlet_with_data_dtype(n_samples=nsamples))
-    
-        # Generating hitlets and copying relevant information from hits to hitlets.
-        # These hitlets are not stored in the end since this array also contains a data
-        # field which we will drop later.
-        strax.refresh_hit_to_hitlets(hits, temp_hitlets)
+        temp_hitlets = strax.create_hitlets_from_hits(hits,
+                                                      self.config['save_outside_hits_nv'],
+                                                      self.channel_range,
+                                                      chunk_start=start,
+                                                      chunk_end=end)
         del hits
-        
+
         # Get hitlet data and split hitlets:
-        strax.get_hitlets_data(temp_hitlets, records_nv, to_pe=self.to_pe)
+        temp_hitlets = strax.get_hitlets_data(temp_hitlets, records_nv, to_pe=self.to_pe)
 
         temp_hitlets = strax.split_peaks(temp_hitlets,
                                          records_nv,
@@ -137,6 +122,17 @@ class nVETOHitlets(strax.Plugin):
         return hitlets
 
 
+def remove_switched_off_channels(hits, to_pe):
+    """Removes hits which were found in a channel without any gain.
+    :param hits: Hits found in records.
+    :param to_pe: conversion factor from ADC per sample.
+    :return: Hits
+    """
+    channel_off = np.argwhere(to_pe == 0).flatten()
+    mask_off = np.isin(hits['channel'], channel_off)
+    hits = hits[~mask_off]
+    return hits
+
 @export
 @strax.takes_config(
     strax.Option(
@@ -146,7 +142,7 @@ class nVETOHitlets(strax.Plugin):
         help='Save (left, right) samples besides hits; cut the rest'),
     strax.Option(
         'hit_min_amplitude_mv',
-        default=20, track=True,
+        default=80, track=True,
         child_option=True, parent_option_name='hit_min_amplitude_nv',
         help='Minimum hit amplitude in ADC counts above baseline. '
              'Specify as a tuple of length 120, or a number.'),
@@ -171,9 +167,9 @@ class nVETOHitlets(strax.Plugin):
         default=False, track=True,
         child_option=True, parent_option_name='entropy_square_data_nv',
         help='Parameter which decides if data is first squared before normalized and compared to the template.'),
-    strax.Option('gain_model_mv',
+    strax.Option('gain_model_mv', default=("to_pe_constant", "adc_mv"),
                  child_option=True, parent_option_name='gain_model_nv',
-             help='PMT gain model. Specify as (model_type, model_config)'),
+                 help='PMT gain model. Specify as (model_type, model_config)'),
 )
 class muVETOHitlets(nVETOHitlets):
     __doc__ = MV_PREAMBLE + nVETOHitlets.__doc__
