@@ -150,71 +150,6 @@ def _correct_baseline(records):
     return records
 
 
-@export
-@numba.njit(cache=True, nogil=True)
-def clean_up_empty_records(records, record_links, only_last=True):
-    """
-    Function which deletes empty records. Empty means data is completely
-    zero.
-
-    :param records: Records which shall be checked.
-    :param record_links: Tuple of previous and next records.
-    :param only_last: If true only last fragments of a pulse are deleted.
-    :return: non-empty records
-
-    Note:
-        If only_last is false, also records within a pulse can be deleted.
-        This may lead to unwanted consequences if it not taken into account.
-    """
-    indicies_to_keep = np.zeros(len(records), dtype=np.int32)
-    n_indicies = 0
-    for rind, r in enumerate(records):
-        if only_last:
-            m_first = record_links[0][rind] == strax.NO_RECORD_LINK  #
-            m_in_between = record_links[1][rind] != strax.NO_RECORD_LINK
-            if m_first or m_in_between:
-            # we are not the last record as we don't have a link on the left (i.e. are first) or have a link on the
-            # right
-                indicies_to_keep[n_indicies] = rind
-                n_indicies += 1
-                continue
-
-        if np.any(r['data'] != 0):
-            indicies_to_keep[n_indicies] = rind
-            n_indicies += 1
-            continue
-
-        # If we arrive here this means we will remove this record
-        # Hence we have to update the pulse_lengths accordingly:
-        length = r['length']
-
-        MAX_RECORD_I  = 500  # Do not want to be stuck forever
-
-        left_links, right_links = record_links  # Just to make for loop more explicit
-        for ind, neighbors in enumerate((left_links, right_links)):
-            if only_last & ind:
-                continue
-
-            neighbor_i = rind
-            ntries = 0
-
-            # Looping over all left/right neighbors and update pulse_length
-            while ntries < MAX_RECORD_I:
-                neighbor_i = neighbors[neighbor_i]
-                if neighbor_i == strax.NO_RECORD_LINK:
-                    # No neighbor anymore
-                    break
-                else:
-                    records[neighbor_i]['pulse_length'] -= length
-                ntries += 1
-            if ntries == MAX_RECORD_I:
-                mes = 'Found more than 500 links for a single pulse this is odd.'
-
-                raise TimeoutError(mes)
-
-    return records[indicies_to_keep[:n_indicies]]
-
-
 @export
 @strax.takes_config(
     strax.Option(
@@ -224,13 +159,13 @@ def clean_up_empty_records(records, record_links, only_last=True):
         help='Save (left, right) samples besides hits; cut the rest'),
     strax.Option(
         'baseline_samples_mv',
-        default=10, track=True,
+        default=100, track=True,
         child_option=True, parent_option_name='baseline_samples_nv',
         help='Number of samples to use at the start of the pulse to determine '
              'the baseline'),
     strax.Option(
         'hit_min_amplitude_mv',
-        default=20, track=True,
+        default=80, track=True,
         child_option=True, parent_option_name='hit_min_amplitude_nv',
         help='Minimum hit amplitude in ADC counts above baseline. '
              'Specify as a tuple of length n_nveto_pmts, or a number.'),
